@@ -32,8 +32,6 @@
 
 #include "inlinepixbufs.h"
 
-#include "gdk-compat.h"
-
 #include <string.h>
 #include <stdlib.h>
 
@@ -522,7 +520,7 @@ meta_image_window_new (Display *xdisplay,
   gtk_window_set_screen (GTK_WINDOW (iw->window), gscreen);
  
   gtk_widget_realize (iw->window);
-  iw->pixmap = gdk_pixmap_new (iw->window->window,
+  iw->pixmap = gdk_pixmap_new (gtk_widget_get_window (iw->window),
                                max_width, max_height,
                                -1);
   
@@ -560,6 +558,7 @@ meta_image_window_set (MetaImageWindow *iw,
                        int              x,
                        int              y)
 {
+  GdkWindow *window;
   cairo_t *cr;
 
   /* We use a back pixmap to avoid having to handle exposes, because
@@ -568,7 +567,7 @@ meta_image_window_set (MetaImageWindow *iw,
    */
 
   gdk_draw_pixbuf (iw->pixmap,
-                   iw->window->style->black_gc,
+                   gtk_widget_get_style (iw->window)->black_gc,
 		   pixbuf,
                    0, 0,
                    0, 0,
@@ -581,16 +580,17 @@ meta_image_window_set (MetaImageWindow *iw,
   cairo_paint (cr);
   cairo_destroy (cr);
 
-  gdk_window_set_back_pixmap (iw->window->window,
+  window = gtk_widget_get_window (iw->window);
+  gdk_window_set_back_pixmap (window,
                               iw->pixmap,
                               FALSE);
   
-  gdk_window_move_resize (iw->window->window,
+  gdk_window_move_resize (window,
                           x, y,
                           gdk_pixbuf_get_width (pixbuf),
                           gdk_pixbuf_get_height (pixbuf));
 
-  gdk_window_clear (iw->window->window);
+  gdk_window_clear (window);
 }
 
 static GdkColormap*
@@ -620,7 +620,7 @@ get_cmap (GdkPixmap *pixmap)
 
   /* Be sure we aren't going to blow up due to visual mismatch */
   if (cmap &&
-      (gdk_colormap_get_visual (cmap)->depth !=
+      (gdk_visual_get_depth (gdk_colormap_get_visual (cmap)) !=
        gdk_drawable_get_depth (pixmap)))
     {
       cmap = NULL;
@@ -745,10 +745,8 @@ meta_ui_get_default_window_icon (MetaUI *ui)
                                                    0,
                                                    NULL);
       else
-          default_icon = gtk_icon_theme_load_icon (theme,
-                                                   "gtk-missing-image",
-                                                   META_ICON_WIDTH,
-                                                   0,
+        default_icon = gdk_pixbuf_new_from_inline (-1, window_data,
+                                                   FALSE,
                                                    NULL);
 
       g_assert (default_icon);
@@ -780,10 +778,8 @@ meta_ui_get_default_mini_icon (MetaUI *ui)
                                                    0,
                                                    NULL);
       else
-          default_icon = gtk_icon_theme_load_icon (theme,
-                                                   "gtk-missing-image",
-                                                   META_MINI_ICON_WIDTH,
-                                                   0,
+        default_icon = gdk_pixbuf_new_from_inline (-1, mini_window_data,
+                                                   FALSE,
                                                    NULL);
 
       g_assert (default_icon);
